@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: client.h,v 1.26 2000/02/02 23:51:04 nisse Exp $ */
+ * $Id: client.h,v 1.27 2000/02/05 17:05:33 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -62,9 +62,9 @@ extern struct channel_request_command request_shell;
 extern struct command client_io;
 #define CLIENT_START_IO (&client_io.super)
 
-struct ssh_channel *make_client_session(struct io_fd *in,
-					struct io_fd *out,
-					struct io_fd *err,
+struct ssh_channel *make_client_session(struct lsh_fd *in,
+					struct lsh_fd *out,
+					struct lsh_fd *err,
 					UINT32 max_window,
 					int *exit_status);
 
