@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.18 1999/12/12 19:33:54 nisse Exp $
+ * $Id: connection_commands.c,v 1.21 2000/02/07 20:52:52 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -145,6 +145,8 @@ do_line(struct line_handler **h,
   CAST(connection_line_handler, closure, *h);
   UINT32 protover_len, swver_len, comment_len;
   UINT8 *protover, *swver, *comment;
+
+  struct ssh_connection *connection = closure->connection;
   
   switch(split_version_string(length, line, 
 			      &protover_len, &protover, 
@@ -169,7 +171,7 @@ do_line(struct line_handler **h,
 		assert(closure->mode == CONNECTION_SERVER);
 	      
 		/* Sending keyexchange packet was delayed. Do it now */
-		initiate_keyexchange(closure->connection,
+		initiate_keyexchange(connection,
 				     closure->mode);
 	      }
 #endif /* WITH_SSH1_FALLBACK */
@@ -179,7 +181,7 @@ do_line(struct line_handler **h,
 		 /* FIXME: Perhaps do a numerical comparison here? */
 		 && (memcmp(swver + 4, "13", 2) <= 0) )
 	      {
-		closure->connection->peer_flags
+		connection->peer_flags
 		  |= (PEER_SSH_DSS_KLUDGE | PEER_SERVICE_ACCEPT_KLUDGE
 		      | PEER_USERAUTH_REQUEST_KLUDGE | PEER_SEND_NO_DEBUG);
 	      }
@@ -188,22 +190,25 @@ do_line(struct line_handler **h,
 	    new = 
 	      make_read_packet(
 		make_packet_unpad(
-		  closure->connection,
+		  connection,
 		  make_packet_inflate(
-		    make_packet_debug(&closure->connection->super, "received"),
-		    closure->connection
+		    make_packet_debug(&connection->super,
+				      (connection->debug_comment
+				       ? ssh_format("%lz received", connection->debug_comment)
+				       : ssh_format("Received"))),
+		    connection
 		    )
 		  ),
-		closure->connection
+		connection
 		);
 	    
-	    closure->connection->versions[!closure->mode]
+	    connection->versions[!closure->mode]
 	      = ssh_format("%ls", length, line);
 
 	    verbose("Client version: %pS\n"
 		    "Server version: %pS\n",
-		    closure->connection->versions[CONNECTION_CLIENT],
-		    closure->connection->versions[CONNECTION_SERVER]);
+		    connection->versions[CONNECTION_CLIENT],
+		    connection->versions[CONNECTION_SERVER]);
 
 	    *r = new;
 	    return;
@@ -231,7 +236,7 @@ do_line(struct line_handler **h,
 	  KILL(closure);
 	  *h = NULL;
 
-	  EXCEPTION_RAISE(closure->connection->e,
+	  EXCEPTION_RAISE(connection->e,
 			  make_protocol_exception
 			  (SSH_DISCONNECT_PROTOCOL_VERSION_NOT_SUPPORTED,
 			   NULL));
@@ -244,7 +249,7 @@ do_line(struct line_handler **h,
       KILL(closure);
       *h = NULL;
       
-      PROTOCOL_ERROR(closure->connection->e,
+      PROTOCOL_ERROR(connection->e,
 		     "Incorrectly version string.");
       
       return;
@@ -277,7 +282,8 @@ make_connection_read_line(struct ssh_connection *connection, int mode,
 
 struct handshake_info *
 make_handshake_info(int mode,
-		    const char *id,
+		    const char *id_comment,
+		    const char *debug_comment,
 		    UINT32 block_size,
 		    struct randomness *r,
 		    struct alist *algorithms,
@@ -286,7 +292,8 @@ make_handshake_info(int mode,
 {
   NEW(handshake_info, self);
   self->mode = mode;
-  self->id_comment = id;
+  self->id_comment = id_comment;
+  self->debug_comment = debug_comment;
   self->block_size = block_size;
   self->random = r;
   self->algorithms = algorithms;
@@ -321,7 +328,7 @@ do_handshake(struct command *s,
 	     struct exception_handler *e)
 {
   CAST(handshake_command_2, self, s);
-  CAST(io_fd, fd, x);
+  CAST(lsh_fd, fd, x);
   struct lsh_string *version;
   struct ssh_connection *connection;
     
@@ -365,8 +372,9 @@ do_handshake(struct command *s,
    * EXC_FINISH_READ exception. */
   
   connection = make_ssh_connection
-    (c, make_exc_finish_read_handler(&fd->super,
-				     e, HANDLER_CONTEXT));
+    (self->info->debug_comment, 
+     c,
+     make_exc_finish_read_handler(fd, e, HANDLER_CONTEXT));
   
   connection_init_io
     (connection, 
@@ -374,7 +382,7 @@ do_handshake(struct command *s,
 		    make_buffered_read
 		    (BUF_SIZE,
 		     make_connection_read_line(connection, self->info->mode,
-					       fd->super.fd, self->info->fallback)),
+					       fd->fd, self->info->fallback)),
 		    self->info->block_size,
 		    make_connection_close_handler(connection))
      ->write_buffer->super,
@@ -429,9 +437,7 @@ STATIC_COLLECT_2_FINAL(collect_handshake_2);
 struct collect_info_1 handshake_command =
 STATIC_COLLECT_1(&collect_info_handshake_2);
 
-#if 0
-
-/* ;; GABA:
+/* GABA:
    (class
      (name connection_remember_command)
      (super command)
@@ -439,9 +445,11 @@ STATIC_COLLECT_1(&collect_info_handshake_2);
        (connection object ssh_connection)))
 */
 
-static int do_connection_remember(struct command *s,
-				  struct lsh_object *x,
-				  struct command_continuation *c)
+static void
+do_connection_remember(struct command *s,
+		       struct lsh_object *x,
+		       struct command_continuation *c,
+		       struct exception_handler *e UNUSED)
 {
   CAST(connection_remember_command, self, s);
   CAST_SUBTYPE(resource, resource, x);
@@ -449,26 +457,18 @@ static int do_connection_remember(struct command *s,
   if (resource)
     REMEMBER_RESOURCE(self->connection->resources, resource);
 
-  return COMMAND_RETURN(c, resource);
+  COMMAND_RETURN(c, resource);
 }
 
-static struct lsh_object *
-collect_connection_remember(struct collect_info_1 *info,
-			     struct lsh_object *x)
+COMMAND_SIMPLE(connection_remember)
 {
-  CAST(ssh_connection, connection, x);
+  CAST(ssh_connection, connection, a);
   NEW(connection_remember_command, self);
 
-  assert(!info->next);
-
   self->super.call = do_connection_remember;
   self->connection = connection;
 
   return &self->super.super;
 }
 
-struct command connection_remember_command =
-STATIC_COMMAND(collect_connection_remember);
-
-#endif
 
