@@ -1,6 +1,6 @@
 /* io_commands.h
  *
- * $Id: io_commands.h,v 1.11 1999/12/07 21:59:27 nisse Exp $
+ * $Id: io_commands.h,v 1.12 2000/02/05 17:34:20 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -72,15 +72,6 @@ extern struct io_read_fd io_read_stdin;
 #define IO_READ_STDIN (&io_read_stdin.super.super)
 
 
-/* Returned by listen */
-/* GABA:
-   (class
-     (name listen_value)
-     (vars
-       (fd object io_fd)
-       (peer object address_info)))
-*/
-
 struct command *make_listen_command(struct command *callback,
 				    struct io_backend *backend);
 
