@@ -1,6 +1,6 @@
 /* proxy.h
  *
- * $Id: proxy.h,v 1.2 2000/01/12 22:40:12 nisse Exp $ */
+ * $Id: proxy.h,v 1.3 2000/02/06 22:20:21 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,6 +28,7 @@
 #include "command.h"
 
 extern struct collect_info_1 chain_connections;
+#define CHAIN_CONNECTIONS (&chain_connections.super.super.super)
 
 struct command *
 make_proxy_connection_service(struct alist *server_requests,
@@ -36,5 +37,12 @@ make_proxy_connection_service(struct alist *server_requests,
 struct command *
 make_proxy_offer_service(struct alist *services);
 
+struct channel_open *
+make_proxy_open_direct_tcpip(void);
+
+struct channel_open *
+make_proxy_open_forwarded_tcpip(void);
+
+
 
 #endif /* LSH_PROXY_H_INCLUDED */
