@@ -1,6 +1,6 @@
 /* proxy_userauth.c
  *
- * $Id: proxy_userauth.c,v 1.2 2000/01/12 22:40:14 nisse Exp $ */
+ * $Id: proxy_userauth.c,v 1.3 2000/01/22 21:46:13 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -222,6 +222,8 @@ do_handle_userauth(struct packet_handler *c,
       CAST_SUBTYPE(proxy_userauth, auth, ALIST_GET(closure->methods, method));
       CAST_SUBTYPE(command, service,
 		   ALIST_GET(closure->services, requested_service));
+
+      connection_lock(connection);
       
       if (auth && service)
 	{
@@ -283,6 +285,8 @@ do_proxy_userauth_continuation(struct command_continuation *c,
   CAST(delayed_apply, action, x);
   int i;
 
+  connection_unlock(self->connection);
+
   /* Ignore any further userauth messages. */
   for (i = SSH_FIRST_USERAUTH_GENERIC; i < SSH_FIRST_CONNECTION_GENERIC; i++) 
     self->connection->dispatch[i] = self->connection->ignore;
