@@ -2,7 +2,7 @@
  *
  * A read handler for application data.
  *
- * $Id: read_data.h,v 1.12 2000/02/05 17:20:07 nisse Exp $ */
+ * $Id: read_data.h,v 1.13 2000/02/15 18:30:08 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -28,8 +28,10 @@
 
 #include "channel.h"
 
-struct io_callback *make_read_data(struct ssh_channel *channel,
-				   struct abstract_write *write);
+struct io_callback *
+make_read_data(struct ssh_channel *channel,
+	       UINT32 overhead,
+	       struct abstract_write *write);
 
 #if 0
 struct exception_handler *
