@@ -2,7 +2,7 @@
  *
  * Reads a sexp in given form from, and writes it in given form.
  *
- * $Id: sexp_conv.c,v 1.11 1999/11/16 22:13:43 nisse Exp $ */
+ * $Id: sexp_conv.c,v 1.13 2000/02/06 18:55:17 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -251,17 +251,17 @@ int main(int argc, char **argv)
 		   make_read_sexp_command(options->input, !options->once),
 		   options->transform,
 		   options->print,
-		   &(io_write(make_io_fd(backend,
+		   &(io_write(make_lsh_fd(backend,
 					 STDOUT_FILENO,
 					 e),
 			      SEXP_BUFFER_SIZE,
 			      NULL)
 		     ->write_buffer->super)));
 
-    struct io_fd *in = make_io_fd(backend, STDIN_FILENO, e);
+    struct lsh_fd *in = make_lsh_fd(backend, STDIN_FILENO, e);
 
     /* Fixing the exception handler creates a circularity */
-    e->parent = make_exc_finish_read_handler(&in->super,
+    e->parent = make_exc_finish_read_handler(in,
 					     &default_exception_handler,
 					     HANDLER_CONTEXT);
     
