@@ -1,6 +1,6 @@
 /* tty.h
  *
- * $Id: tty.c,v 1.7 1999/11/16 22:13:48 nisse Exp $ */
+ * $Id: tty.c,v 1.8 2000/02/02 22:44:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -60,7 +60,7 @@ int tty_makeraw(int fd)
   return 0;
 }
 
-int tty_getwinsize(int fd, int *w, int *h, int *wp, int *hp)
+int tty_getwinsize(int fd, UINT32 *w, UINT32 *h, UINT32 *wp, UINT32 *hp)
 {
   struct winsize ws;
   int rc;
@@ -77,7 +77,7 @@ int tty_getwinsize(int fd, int *w, int *h, int *wp, int *hp)
   return 0;
 }
 
-int tty_setwinsize(int fd, int w, int h, int wp, int hp)
+int tty_setwinsize(int fd, UINT32 w, UINT32 h, UINT32 wp, UINT32 hp)
 {
   struct winsize ws;
   
